Enum rustdoc_seeker::TypeItem [−][src]
pub enum TypeItem {
Module(Atom),
ExternCrate(Atom),
Import(Atom),
Struct(Atom),
Enum(Atom),
Function(Atom),
Typedef(Atom),
Static(Atom),
Trait(Atom),
Impl(Atom),
TyMethod(Atom),
Method(Atom),
StructField(Atom),
Variant(Atom),
Macro(Atom),
Primitive(Atom),
AssociatedType(Atom),
Constant(Atom),
AssociatedConst(Atom),
Union(Atom),
ForeignType(Atom),
Keyword(Atom),
Existential(Atom),
}TypeItem represent an item with type,
Use Display or fmt_url to get the type dot name format of the item.
Example
assert_eq!("module.vec", TypeItme::Module("vec")); assert_eq!("macro.vec", TypeItme::Macro("vec")); assert_eq!("fn.vec", TypeItme::Function("vec")); // the only two exceptions assert_eq!("type.vec", TypeItme::Typedef("vec")); // the only two exceptions
Variants
Module(Atom)ExternCrate(Atom)Import(Atom)Struct(Atom)Enum(Atom)Function(Atom)Typedef(Atom)Static(Atom)Trait(Atom)Impl(Atom)TyMethod(Atom)Method(Atom)StructField(Atom)Variant(Atom)Macro(Atom)Primitive(Atom)AssociatedType(Atom)Constant(Atom)AssociatedConst(Atom)Union(Atom)ForeignType(Atom)Keyword(Atom)Existential(Atom)
Methods
impl TypeItem[src]
impl TypeItemTrait Implementations
impl Clone for TypeItem[src]
impl Clone for TypeItemfn clone(&self) -> TypeItem[src]
fn clone(&self) -> TypeItemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for TypeItem[src]
impl Debug for TypeItemfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for TypeItem[src]
impl Eq for TypeItemimpl PartialEq for TypeItem[src]
impl PartialEq for TypeItemfn eq(&self, other: &TypeItem) -> bool[src]
fn eq(&self, other: &TypeItem) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TypeItem) -> bool[src]
fn ne(&self, other: &TypeItem) -> boolThis method tests for !=.
impl AsRef<Atom> for TypeItem[src]
impl AsRef<Atom> for TypeItemimpl Display for TypeItem[src]
impl Display for TypeItem