Enum rustdoc_seeker::TypeItem

source ·
pub enum TypeItem {
Show 23 variants Module(Atom), ExternCrate(Atom), Import(Atom), Struct(Atom), Enum(Atom), Function(Atom), Typedef(Atom), Static(Atom), Trait(Atom), Impl(Atom), TyMethod(Atom), Method(Atom), StructField(Atom), Variant(Atom), Macro(Atom), Primitive(Atom), AssociatedType(Atom), Constant(Atom), AssociatedConst(Atom), Union(Atom), ForeignType(Atom), Keyword(Atom), Existential(Atom),
}
TypeItem represent an item with type, Use Display to get the type dot name format of the item

Example

assert_eq!("module.vec", TypeItme::Module(vec));
assert_eq!("macro.vec", TypeItme::Macro(vec));

assert_eq!("fn.vec", TypeItme::Function(vec)); // the only two exceptions
assert_eq!("type.vec", TypeItme::Typedef(vec)); // the only two exceptions

Variants



Module(Atom)



ExternCrate(Atom)



Import(Atom)



Struct(Atom)



Enum(Atom)



Function(Atom)



Typedef(Atom)



Static(Atom)



Trait(Atom)



Impl(Atom)



TyMethod(Atom)



Method(Atom)



StructField(Atom)



Variant(Atom)



Macro(Atom)



Primitive(Atom)



AssociatedType(Atom)



Constant(Atom)



AssociatedConst(Atom)



Union(Atom)



ForeignType(Atom)



Keyword(Atom)



Existential(Atom)

Implementations

source

impl TypeItem

source

pub fn new(tag: usize, data: Atom) -> TypeItem